@@ -8,12 +8,17 @@
   bill@newbreedsoftware.com
   http://www.newbreedsoftware.com/vectoroids/
   
-  November 30, 2001 - April 13, 2002
+  November 30, 2001 - April 20, 2002
 */
 
-#define VER_VERSION "1.0.8"
-#define VER_DATE "2002.04.13"
+#define VER_VERSION "1.1.0"
+#define VER_DATE "2002.04.20"
+
+#ifndef EMBEDDED
 #define STATE_FORMAT_VERSION "2001.12.01"
+#else
+#define STATE_FORMAT_VERSION "2001.12.01e"
+#endif
 
 
 #include <stdio.h>
@@ -39,8 +44,13 @@
   #define NUM_BULLETS 3
 #endif
 
-#define NUM_ASTEROIDS 20
-#define NUM_BITS 50
+#ifndef EMBEDDED
+  #define NUM_ASTEROIDS 20
+  #define NUM_BITS 50
+#else
+  #define NUM_ASTEROIDS 15
+  #define NUM_BITS 25
+#endif
 
 #define AST_SIDES 6
 #ifndef EMBEDDED
@@ -1231,8 +1241,8 @@ int game(void)
 		  Mix_PlayChannel(CHAN_THRUST, sounds[SND_THRUST], -1);
 #else
 		  Mix_PlayChannel(-1, sounds[SND_THRUST], 0);
-		}
 #endif
+		}
 	    }
 #endif
 	}
@@ -1556,10 +1566,19 @@ int game(void)
 	  
 	  if (up_pressed)
 	    {
+#ifndef EMBEDDED
 	      draw_segment(0, 0, mkcolor(255, 255, 255),
 			   (rand() % 20), 180, mkcolor(255, 0, 0),
 			   x >> 4, y >> 4,
 			   angle);
+#else
+	      i = (rand() % 128) + 128;
+
+	      draw_segment(0, 0, mkcolor(255, i, i),
+			   (rand() % 20), 180, mkcolor(255, i, i),
+			   x >> 4, y >> 4,
+			   angle);
+#endif
 	    }
 	}
       
@@ -1647,17 +1666,29 @@ int game(void)
 
       
       /* Draw score: */
-      
+     
+#ifndef EMBEDDED
       sprintf(str, "%.6d", score);
       draw_text(str, 3, 3, 14, mkcolor(255, 255, 255));
       draw_text(str, 4, 4, 14, mkcolor(255, 255, 255));
+#else
+      sprintf(str, "%.6d", score);
+      draw_text(str, 3, 3, 10, mkcolor(255, 255, 255));
+      draw_text(str, 4, 4, 10, mkcolor(255, 255, 255));
+#endif
 
 
       /* Level: */
       
+#ifndef EMBEDDED
       sprintf(str, "%d", level);
       draw_text(str, (WIDTH - 14) / 2, 3, 14, mkcolor(255, 255, 255));
       draw_text(str, (WIDTH - 14) / 2 + 1, 4, 14, mkcolor(255, 255, 255));
+#else
+      sprintf(str, "%d", level);
+      draw_text(str, (WIDTH - 14) / 2, 3, 10, mkcolor(255, 255, 255));
+      draw_text(str, (WIDTH - 14) / 2 + 1, 4, 10, mkcolor(255, 255, 255));
+#endif
 
       
       /* Draw lives: */
@@ -1722,10 +1753,16 @@ int game(void)
 	{
 	  if ((counter % 2) == 0)
 	    text_zoom--;
-	  
+
+#ifndef EMBEDDED 
 	  draw_text(zoom_str, (WIDTH - (strlen(zoom_str) * text_zoom)) / 2,
 		    (HEIGHT - text_zoom) / 2,
 		    text_zoom, mkcolor(text_zoom * (256 / ZOOM_START), 0, 0));
+#else
+	  draw_text(zoom_str, (WIDTH - (strlen(zoom_str) * text_zoom)) / 2,
+		    (HEIGHT - text_zoom) / 2,
+		    text_zoom, mkcolor(text_zoom * (256 / ZOOM_START), 128, 128));
+#endif
 	}
 
 
@@ -2616,7 +2653,11 @@ void add_bullet(int x, int y, int a, int xm, int ym)
   
   if (found != -1)
     {
+#ifndef EMBEDDED
       bullets[found].timer = 50;
+#else
+      bullets[found].timer = 30;
+#endif
       
       bullets[found].x = x;
       bullets[found].y = y;
